==> ui-v0.0.4.zip: delfi/ui/app/utils/api.js <==
import axios from 'axios';

import config from './config';

/*
 *get stops-count-gtfs
 */
export async function getStopsCountGtfs(){
    //console.log('stops:getStopsCountGtfs() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfs() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de
 */
export async function getStopsCountGtfsDe(){
    //console.log('stops:getStopsCountGtfsDe() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDe() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-not-dhid
 */
export async function getStopsCountGtfsDeNotDhid(){
    //console.log('stops:getStopsCountGtfsDeNotDhid() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-not-dhid`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeNotDhid() Done.');
    return count;
};

/*
 *get stops-count-zhv
 */
export async function getStopsCountZhv(){
    //console.log('stops:getStopsCountZhv() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-zhv`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountZhv() Done.');
    return count;
};

==> ui-v0.0.5.zip: delfi/ui/app/utils/api.js <==
import axios from 'axios';

import config from './config';

/*
 *get stops-count-gtfs
 */
export async function getStopsCountGtfs(){
    //console.log('stops:getStopsCountGtfs() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfs() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de
 */
export async function getStopsCountGtfsDe(){
    //console.log('stops:getStopsCountGtfsDe() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDe() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-not-dhid
 */
export async function getStopsCountGtfsDeNotDhid(){
    //console.log('stops:getStopsCountGtfsDeNotDhid() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-not-dhid`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeNotDhid() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-hb
 */
export async function getStopsCountGtfsDeHb(){
    //console.log('stops:getStopsCountGtfsDeHb() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-hb`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeHb() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-hb-not-dhid
 */
export async function getStopsCountGtfsDeHbNotDhid(){
    //console.log('stops:getStopsCountGtfsDeHbNotDhid() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-hb-not-dhid`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeHbNotDhid() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-hh-not-dhid
 */
export async function getStopsCountGtfsDeHhNotDhid(){
    //console.log('stops:getStopsCountGtfsDeHhNotDhid() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-hh-not-dhid`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeHhNotDhid() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-ni-not-dhid
 */
export async function getStopsCountGtfsDeNiNotDhid(){
    //console.log('stops:getStopsCountGtfsDeNiNotDhid() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-ni-not-dhid`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeNiNotDhid() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-hh
 */
export async function getStopsCountGtfsDeHh(){
    //console.log('stops:getStopsCountGtfsDeHh() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-hh`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeHh() Done.');
    return count;
};

/*
 *get stops-count-gtfs-de-ni
 */
export async function getStopsCountGtfsDeNi(){
    //console.log('stops:getStopsCountGtfsDeNi() Start...');

    let count=null;
    try {
	//TODO handle errors: https://www.valentinog.com/blog/await-react/
	const address = `${config.API}stops-count-gtfs-de-ni`;
	const res = await axios.get(address);
	count=res.data[0].count;
    } catch (err) {
        console.error('err.message: ' + err.message);
	count=-1;
    }
    //console.log('stops:getStopsCountGtfsDeNi() Done.');
    return count;
};
